@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class Config(AppConfig):
     name = "unicef_locations"
-    label = "locations"
+    label = "unicef_locations"
